==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/FTPURLConnection__24ClosingOutputStream.h <==
// class gnu.java.net.protocol.ftp.FTPURLConnection$ClosingOutputStream

// class file dependencies
// @dep_class 4000fa4074f15e25 gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream_H_
#define _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$refs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vmethods	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtable	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$method$_init$cc164e85b15c6e5e(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$method_info$close$6aba8b329fddcd79;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vmethods	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_refs {
	struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$refs {
    _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_refs	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object {
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/FTPURLConnection__24ClosingOutputStream.h <==
// class gnu.java.net.protocol.ftp.FTPURLConnection$ClosingOutputStream

// class file dependencies
// @dep_class 4000fa4074f15e25 gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream_H_
#define _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$refs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vmethods	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtable	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$method$_init$cc164e85b15c6e5e(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$method_info$close$6aba8b329fddcd79;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vmethods	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_refs {
	struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$refs {
    _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_refs	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$object {
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$vtype _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingOutputStream_H_ */
